pub struct UserDirs { /* private fields */ }Expand description
UserDirs provides paths of user-facing standard directories, following
the conventions of the operating system the library is running on.
This corresponds to directories::UserDirs, except that the
functions open the directories and returns Dirs instead of returning
Paths.
Unlike directories::UserDirs, the *_dir functions return Dirs
rather than Paths, because absolute paths don’t interoperate well with
the capability model.
Implementations
Sourceimpl UserDirs
impl UserDirs
Sourcepub fn new() -> Option<Self>
pub fn new() -> Option<Self>
Creates a UserDirs struct which holds the paths to user-facing
directories for audio, font, video, etc. data on the system.
This corresponds to directories::UserDirs::new.
Sourcepub fn home_dir(&self, ambient_authority: AmbientAuthority) -> Result<Dir>
pub fn home_dir(&self, ambient_authority: AmbientAuthority) -> Result<Dir>
Returns the user’s home directory.
This corresponds to directories::UserDirs::home_dir.
Ambient Authority
This function makes use of ambient authority to access the user directories.
Sourcepub fn audio_dir(&self, ambient_authority: AmbientAuthority) -> Result<Dir>
pub fn audio_dir(&self, ambient_authority: AmbientAuthority) -> Result<Dir>
Returns the user’s audio directory.
This corresponds to directories::UserDirs::audio_dir.
Ambient Authority
This function makes use of ambient authority to access the user directories.
Sourcepub fn desktop_dir(&self, ambient_authority: AmbientAuthority) -> Result<Dir>
pub fn desktop_dir(&self, ambient_authority: AmbientAuthority) -> Result<Dir>
Returns the user’s desktop directory.
This corresponds to directories::UserDirs::desktop_dir.
Ambient Authority
This function makes use of ambient authority to access the user directories.
Sourcepub fn document_dir(&self, ambient_authority: AmbientAuthority) -> Result<Dir>
pub fn document_dir(&self, ambient_authority: AmbientAuthority) -> Result<Dir>
Returns the user’s document directory.
This corresponds to directories::UserDirs::document_dir.
Ambient Authority
This function makes use of ambient authority to access the user directories.
Sourcepub fn download_dir(&self, ambient_authority: AmbientAuthority) -> Result<Dir>
pub fn download_dir(&self, ambient_authority: AmbientAuthority) -> Result<Dir>
Returns the user’s download directory.
This corresponds to directories::UserDirs::download_dir.
Ambient Authority
This function makes use of ambient authority to access the user directories.
Sourcepub fn font_dir(&self, ambient_authority: AmbientAuthority) -> Result<Dir>
pub fn font_dir(&self, ambient_authority: AmbientAuthority) -> Result<Dir>
Returns the user’s font directory.
This corresponds to directories::UserDirs::font_dir.
Ambient Authority
This function makes use of ambient authority to access the user directories.
Sourcepub fn picture_dir(&self, ambient_authority: AmbientAuthority) -> Result<Dir>
pub fn picture_dir(&self, ambient_authority: AmbientAuthority) -> Result<Dir>
Returns the user’s picture directory.
This corresponds to directories::UserDirs::picture_dir.
Ambient Authority
This function makes use of ambient authority to access the user directories.
Sourcepub fn public_dir(&self, ambient_authority: AmbientAuthority) -> Result<Dir>
pub fn public_dir(&self, ambient_authority: AmbientAuthority) -> Result<Dir>
Returns the user’s public directory.
This corresponds to directories::UserDirs::public_dir.
Ambient Authority
This function makes use of ambient authority to access the user directories.
Sourcepub fn template_dir(&self, ambient_authority: AmbientAuthority) -> Result<Dir>
pub fn template_dir(&self, ambient_authority: AmbientAuthority) -> Result<Dir>
Returns the user’s template directory.
This corresponds to directories::UserDirs::template_dir.
Ambient Authority
This function makes use of ambient authority to access the user directories.
Sourcepub fn video_dir(&self, ambient_authority: AmbientAuthority) -> Result<Dir>
pub fn video_dir(&self, ambient_authority: AmbientAuthority) -> Result<Dir>
Returns the user’s video directory.
This corresponds to directories::UserDirs::video_dir.
Ambient Authority
This function makes use of ambient authority to access the user directories.